// generated from rosidl_generator_c/resource/idl__type_support.c.em
// with input from rosgraph_msgs:msg/Clock.idl
// generated code does not contain a copyright notice

#include <string.h>

#include "rosgraph_msgs/msg/detail/clock__functions.h"
#include "rosgraph_msgs/msg/detail/clock__type_support.h"
#include "rosidl_typesupport_interface/macros.h"
#include "rosgraph_msgs/msg/detail/clock__struct.h"

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef __cplusplus
}
#endif
